@@ -17,6 +17,8 @@
 #define _GNU_SOURCE 1
 #define _POSIX_PTHREAD_SEMANTICS 1
 #define _TANDEM_SOURCE 1
+#define HAVE_INFINITY 1
+#define HAVE_NAN 1
 #define RUBY_SYMBOL_EXPORT_BEGIN _Pragma("GCC visibility push(default)")
 #define RUBY_SYMBOL_EXPORT_END _Pragma("GCC visibility pop")
 #define HAVE_CRT_EXTERNS_H 1
@@ -25,29 +27,29 @@
 #define HAVE__BOOL 1
 #define HAVE_STDBOOL_H 1
 #define HAVE_SYS_WAIT_H 1
+#define HAVE_GRP_H 1
+#define HAVE_FCNTL_H 1
+#define HAVE_FLOAT_H 1
+#define HAVE_LANGINFO_H 1
 #define HAVE_LIMITS_H 1
+#define HAVE_LOCALE_H 1
+#define HAVE_MALLOC_MALLOC_H 1
+#define HAVE_PWD_H 1
+#define HAVE_SYS_ATTR_H 1
+#define HAVE_SYS_FCNTL_H 1
 #define HAVE_SYS_FILE_H 1
 #define HAVE_SYS_IOCTL_H 1
-#define HAVE_SYS_SYSCALL_H 1
-#define HAVE_FCNTL_H 1
-#define HAVE_SYS_FCNTL_H 1
 #define HAVE_SYS_PARAM_H 1
+#define HAVE_SYS_RESOURCE_H 1
 #define HAVE_SYS_SELECT_H 1
+#define HAVE_SYS_SOCKET_H 1
+#define HAVE_SYS_SYSCALL_H 1
 #define HAVE_SYS_TIME_H 1
 #define HAVE_SYS_TIMES_H 1
-#define HAVE_PWD_H 1
-#define HAVE_GRP_H 1
-#define HAVE_UTIME_H 1
-#define HAVE_SYS_RESOURCE_H 1
-#define HAVE_FLOAT_H 1
-#define HAVE_UCONTEXT_H 1
-#define HAVE_LANGINFO_H 1
-#define HAVE_LOCALE_H 1
-#define HAVE_TIME_H 1
-#define HAVE_SYS_SOCKET_H 1
 #define HAVE_SYS_UIO_H 1
-#define HAVE_MALLOC_MALLOC_H 1
-#define HAVE_SYS_ATTR_H 1
+#define HAVE_TIME_H 1
+#define HAVE_UCONTEXT_H 1
+#define HAVE_UTIME_H 1
 #define HAVE_TYPEOF 1
 #define HAVE_LONG_LONG 1
 #define HAVE_OFF_T 1
@@ -56,7 +58,6 @@
 #define SIZEOF_LONG 8
 #define SIZEOF_LONG_LONG 8
 #define SIZEOF___INT64 0
-#define SIZEOF___INT128 16
 #define SIZEOF_OFF_T 8
 #define SIZEOF_VOIDP 8
 #define SIZEOF_FLOAT 4
@@ -118,13 +119,18 @@
 #define HAVE_VA_ARGS_MACRO 1
 #define NORETURN(x) __attribute__ ((noreturn)) x
 #define DEPRECATED(x) __attribute__ ((deprecated)) x
+#define DEPRECATED_BY(n,x) __attribute__ ((deprecated("by "#n))) x
+#define DEPRECATED_TYPE(mesg,x) x __attribute__ ((deprecated mesg))
 #define NOINLINE(x) __attribute__ ((noinline)) x
+#define WEAK(x) __attribute__ ((weak)) x
+#define HAVE_FUNC_WEAK 1
 #define FUNC_CDECL(x) __attribute__ ((cdecl)) x
 #define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_SYNC_BUILTINS 1
 #define UNREACHABLE __builtin_unreachable()
 #define RUBY_FUNC_EXPORTED __attribute__ ((visibility("default"))) extern
 #define RUBY_FUNCTION_NAME_STRING __func__
+#define ENUM_OVER_INT 1
 #define HAVE_DECL_SYS_NERR 1
 #define HAVE_DECL_GETENV 1
 #define SIZEOF_SIZE_T 8
@@ -165,12 +171,6 @@
 #define SIZEOF_INT64_T 8
 #define HAVE_UINT64_T 1
 #define SIZEOF_UINT64_T 8
-#define HAVE_INT128_T 1
-#define int128_t __int128
-#define SIZEOF_INT128_T SIZEOF___INT128
-#define HAVE_UINT128_T 1
-#define uint128_t unsigned __int128
-#define SIZEOF_UINT128_T SIZEOF_UNSIGNED___INT128
 #define HAVE_INTPTR_T 1
 #define SIZEOF_INTPTR_T 8
 #define HAVE_UINTPTR_T 1
@@ -250,8 +250,10 @@
 #define HAVE_LSTAT 1
 #define HAVE_MALLOC_SIZE 1
 #define HAVE_MBLEN 1
+#define HAVE_MEMSET_S 1
 #define HAVE_WRITEV 1
-#define HAVE_MEMMEM 1
+#define HAVE_MKFIFO 1
+#define HAVE_MKNOD 1
 #define HAVE_MKTIME 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_MEMALIGN 1
@@ -292,6 +294,9 @@
 #define HAVE_UTIMES 1
 #define HAVE_WAIT4 1
 #define HAVE_WAITPID 1
+#if !defined __STDC_WANT_LIB_EXT1__
+#define __STDC_WANT_LIB_EXT1__ 1
+#endif /* !defined __STDC_WANT_LIB_EXT1__ */
 #define HAVE_BUILTIN___BUILTIN_BSWAP16 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP32 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP64 1
@@ -301,8 +306,9 @@
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
+#define HAVE_BSD_QSORT_R 1
 #define ATAN2_INF_C99 1
-#define LGAMMA_R_M0_FIX 1
+#define LGAMMA_R_PM0_FIX 1
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
@@ -329,7 +335,7 @@
 #define HAVE_PTHREAD_SIGMASK 1
 #define HAVE_PTHREAD_SETNAME_NP 1
 #define HAVE_PTHREAD_ATTR_INIT 1
-#define SET_THREAD_NAME(name) pthread_setname_np(name)
+#define SET_CURRENT_THREAD_NAME(name) pthread_setname_np(name)
 #define DEFINE_MCONTEXT_PTR(mc, uc) mcontext_t mc = (uc)->uc_mcontext
 #define HAVE_EXECINFO_H 1
 #define HAVE_LIBUNWIND_H 1
